@@ -59,15 +59,20 @@ stm.init <- function(documents, settings) {
     wprob <- colSums(mat)
     wprob <- wprob/sum(wprob)
     Q <- gram(mat)
-    
+    #verify that there are no zeroes
+    Qsums <- rowSums(Q)
+    if(any(Qsums==0)) stop("Failure in spectral initialization. 
+                           A row of the co-occurence is exactly zero indicating 
+                           that a certain word appears only in documents alone. 
+                           Remove infrequent words or change initialization type.")
     # (2) anchor words
     if(verbose) cat("\t Finding anchor words...\n \t")
-    Qbar <- Q/rowSums(Q)
+    Qbar <- Q/Qsums
     anchor <- fastAnchor(Qbar, K=K, verbose=verbose)
   
     # (3) recoverKL
     if(verbose) cat("\n\t Recovering initialization...\n \t")
-    beta <- recoverL2(Q, anchor, wprob, verbose=TRUE)$A
+    beta <- recoverL2(Q, anchor, wprob, verbose=verbose)$A
     # (4) generate other parameters
     mu <- matrix(0, nrow=(K-1),ncol=1)
     sigma <- diag(20, nrow=(K-1))
